@@ -4,10 +4,11 @@ from AIH_SDK.AIHExceptions import AIHException
 
 class MainSystem(AssetsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.4'):
         super().__init__()
         self._endpoint = 'mainsystems'
-    
+        self._version = api_version
+
     
     def get_design_objects(self):
         """
