@@ -3,9 +3,10 @@ from AIH_SDK.Maintenance.MaintenanceObject import MaintenanceObject
 
 class WorkItem(MaintenanceObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.0'):
         super().__init__()
         self._endpoint = 'WorkItems'
+        self._version = api_version
     
     def get_activities(self, parameters:dict={}):
         """
