@@ -108,10 +108,10 @@ class Object:
         
         if type(self.value) == list:
             for val in self.value:
-                self._client._put(self._api, self._endpoint, val)
+                self._client._put(self._api, self._endpoint, val, self._version)
                 
         elif type(self.value) == dict:
-            self._client._put(self._api, self._endpoint, self.value)
+            self._client._put(self._api, self._endpoint, self.value, self._version)
 
         return self
 
@@ -122,7 +122,7 @@ class Object:
         """
         if type(self.value) == list:
             for i, val in enumerate(self.value):
-                response = self._client._post(self._api, self._endpoint, val)
+                response = self._client._post(self._api, self._endpoint, val, self._version)
 
                 # Sets the id for the posted value
                 if 'id' in response:
@@ -132,7 +132,7 @@ class Object:
                     self.value[i]['id'] = response[key]['id']
                 
         elif type(self.value) == dict:
-            response = self._client._post(self._api, self._endpoint, self.value)
+            response = self._client._post(self._api, self._endpoint, self.value, self._version)
 
             # Sets the id for the posted value
             if 'id' in response:
@@ -153,10 +153,10 @@ class Object:
         
         if type(id_to_delete_) == list:
             for id_to_delete in id_to_delete_:
-                self._client._delete(self._api, self._endpoint, id_to_delete)
+                self._client._delete(self._api, self._endpoint, id_to_delete, self._version)
         
         elif type(id_to_delete_) == str:
-            self._client._delete(self._api, self._endpoint, id_to_delete_)
+            self._client._delete(self._api, self._endpoint, id_to_delete_, self._version)
         
         self.value = None
         
