@@ -3,10 +3,10 @@ from AIH_SDK.Signals.Signal import Signal
 
 class Channel(SignalsObject):
     
-    def __init__(self):
+    def __init__(self, api_version='1.2'):
         super().__init__()
         self._endpoint = 'Channels'
-
+        self._version = api_version
 
     def get_signals(self, from_millis):
         channel_numbers = self.get_value('channelNumber')
